args_generator library

The entry point for the library that provides code generation functionality for generating page arguments in a Flutter application.

This library integrates with the build package to perform source code generation at compile time. It includes a custom generator for generating page arguments used in routing.

Classes

AggregatingArgsBuilder
A Builder that aggregates all classes annotated with @GenerateArgs and generates argument-handling code for them.
PageArgsEmitter
BuildStep-free generator logic used by the CLI runner.
PageArgsGenerator
A generator that creates argument classes for pages annotated with @GenerateArgs.

Functions

aggregatingArgsBuilder(BuilderOptions options) → Builder
Factory method to create an instance of AggregatingArgsBuilder.
argsGenerator(BuilderOptions options) → Builder
pageArgsGenerator(BuilderOptions options) → Builder
Creates a Builder for the args_generator.