PageArgsGenerator class

A generator that creates argument classes for pages annotated with @GenerateArgs.

This generator works by analyzing classes annotated with @GenerateArgs and generating a companion arguments class to facilitate passing data between routes in a Flutter application.

Constructors

PageArgsGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
throwOnUnresolved bool
finalinherited
typeChecker → TypeChecker
no setterinherited

Methods

generate(LibraryReader library, BuildStep buildStep) FutureOr<String>
Generates Dart code for an input Dart library.
inherited
generateForAnnotatedElement(Element element, ConstantReader annotation, BuildStep buildStep) FutureOr<String>
Generates the arguments class for an annotated element.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited